package com.wd.workoffice.ui.activity.mes;

import android.content.Intent;
import android.text.TextUtils;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.chad.library.adapter.base.BaseQuickAdapter;
import com.scwang.smartrefresh.layout.SmartRefreshLayout;
import com.wd.workoffice.R;
import com.wd.workoffice.app.BaseMesBean;
import com.wd.workoffice.app.WorkToolBarActivity;
import com.wd.workoffice.bean.event.AddUserDataEvent;
import com.wd.workoffice.bean.mesBean.UserDataBean;
import com.wd.workoffice.retrofit.RtfUtils;
import com.wd.workoffice.retrofit.WorkObserver;
import com.wd.workoffice.ui.activity.mes.user.MesUserDataAddActivity;
import com.wd.workoffice.ui.activity.mes.user.MesUserDataConditionActivity;
import com.wd.workoffice.ui.activity.mes.user.MesUserDataDetailActivity;
import com.wd.workoffice.ui.activity.mes.user.MesUserDataListCheckActivity;
import com.wd.workoffice.ui.adapter.MesUserDataAdapter;
import com.wd.workoffice.util.WorkUtils;

import org.greenrobot.eventbus.EventBus;
import org.greenrobot.eventbus.Subscribe;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import androidx.annotation.Nullable;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.OnClick;
import flexible.xd.android_base.network.rtfhttp.Transformer;
import io.reactivex.disposables.Disposable;


/**
 * 客户档案
 * author : flexible
 * email : lgd19940421@163.com
 * github: https://github.com/FlexibleXd
 **/
public class MesUserFileListActivity extends WorkToolBarActivity {

    @BindView(R.id.rv_data)
    RecyclerView rvData;
    @BindView(R.id.srl_refresh)
    SmartRefreshLayout srlRefresh;
    @BindView(R.id.tv_go)
    TextView tvGo;
    @BindView(R.id.btn_add)
    Button btnAdd;
    private int page = 1;
    private Map<String, Object> param;
    private List<UserDataBean.ListBean> dataList;
    private MesUserDataAdapter dataAdapter;
    private Map<String, Object> paramMap;
    private JSONArray permission;

    @Override
    protected void initView() {
        ButterKnife.bind(this);
        rvData.setLayoutManager(new LinearLayoutManager(this, RecyclerView.VERTICAL, false));
        tvGo.setVisibility(View.GONE);
        btnAdd.setVisibility(View.GONE);
    }


    @Override
    protected void initData() {
        dataList = new ArrayList<>();
        dataAdapter = new MesUserDataAdapter(R.layout.item_mes_user_data, dataList);
        dataAdapter.bindToRecyclerView(rvData);
        dataAdapter.setEmptyView(R.layout.view_empty_content, rvData);
        param = WorkUtils.pageMesKey();
        paramMap = WorkUtils.simpleParam();
        param.put("pageNum", page);
        param.put("paramMap", paramMap);
        paramMap.put("isCustomerArchives", "1");
        getData();
    }

    private void getButtonPermission() {
        String mesMenuId = WorkUtils.getMesMenuId("市场服务", "历史档案查询");
        if (TextUtils.isEmpty(mesMenuId)) {
            return;
        }
        RtfUtils.getMesRtf().buttonPermission(mesMenuId).compose(Transformer.schedule()).subscribe(new WorkObserver<BaseMesBean>() {
            @Override
            public void doOnSubscribe(Disposable d) {
            }

            @Override
            public void onFail(String errorMsg) {
                hideLoading();
                toast(errorMsg);
            }

            @Override
            public void onSuccess(BaseMesBean data) {
                hideLoading();
                if (!data.isSuccess()) {
                    toast(data.getMessage());
                    return;
                }
                permission = JSON.parseArray(data.getData().toString());
            }
        });
    }

    private void getData() {
        getButtonPermission();
        RtfUtils.getMesRtf().userDataList("1", WorkUtils.convertMapToBody(param)).compose(Transformer.schedule()).subscribe(new WorkObserver<BaseMesBean>() {
            @Override
            public void doOnSubscribe(Disposable d) {
            }

            @Override
            public void onFail(String errorMsg) {
                hideLoading();
                toast(errorMsg);
            }

            @Override
            public void onSuccess(BaseMesBean data) {
                hideLoading();
                if (!data.isSuccess()) {
                    toast(data.getMessage());
                    return;
                }
                List<UserDataBean.ListBean> getList = JSON.parseObject(data.getData().toString(), UserDataBean.class).getList();
                if (page == 1) {
                    srlRefresh.finishRefresh();
                    dataList.clear();
                    dataList.addAll(getList);
                    dataAdapter.notifyDataSetChanged();
                    dataAdapter.loadMoreComplete();
                } else {
                    dataAdapter.loadMoreComplete();
                    dataList.addAll(getList);
                    dataAdapter.notifyDataSetChanged();
                }
                if (getList.size() == 0) {
                    dataAdapter.loadMoreEnd();
                } else {
                    page++;
                }
            }
        });
    }

    @Override
    protected void initEvent() {
        srlRefresh.setOnRefreshListener(refreshLayout -> {
            page = 1;
            param.put("pageNum", page);
            getData();
        });
        dataAdapter.setOnLoadMoreListener(() -> {
            param.put("pageNum", page);
            getData();
        }, rvData);
        dataAdapter.setOnItemClickListener(new BaseQuickAdapter.OnItemClickListener() {
            @Override
            public void onItemClick(BaseQuickAdapter adapter, View view, int position) {
//                boolean isJob = TextUtils.equals(UserKeeper.getInstance().getMesUid(), dataList.get(position).getApprovalUserId());
                startActivity(MesUserDataDetailActivity.class, "from", "1", "id",
                        dataList.get(position).getId(), "status",
                        dataList.get(position).getApprovalStatus() + "",
                        "permission", permission == null ? "" : permission.toJSONString());
            }
        });
    }


    @Override
    protected int layoutId() {
        return R.layout.activity_mes_user_data_list;
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.menu_mes_search, menu);
        return super.onCreateOptionsMenu(menu);
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {
            case R.id.search:
                startActivityForResult(MesUserDataConditionActivity.class, 10001);
                break;
        }
        return super.onOptionsItemSelected(item);
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, @Nullable Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        if (requestCode == 10001 && resultCode == 10001) {
            String returnParam = data.getStringExtra("param");
            paramMap = JSON.parseObject(returnParam, Map.class);
            paramMap.put("isCustomerArchives", "1");
            param.put("paramMap", paramMap);
            page = 1;
            param.put("pageNum", page);
            getData();
        }
    }

    @OnClick({R.id.tv_go, R.id.btn_add})
    public void onViewClicked(View view) {
        switch (view.getId()) {
            case R.id.tv_go:
                startActivity(MesUserDataListCheckActivity.class);
                finish();
                break;
            case R.id.btn_add:
                startActivity(MesUserDataAddActivity.class);
                break;
        }
    }

    @Override
    public void onStart() {
        super.onStart();
        EventBus.getDefault().register(this);
    }

    @Override
    public void onStop() {
        super.onStop();
        EventBus.getDefault().unregister(this);
    }

    @Subscribe
    public void refresh(AddUserDataEvent event) {
        page = 1;
        param.put("pageNum", page);
        getData();
    }
}
